/*
 * icon_factory.cpp
 */

#include <iostream>

#include "icon_factory.h"

IconFactory::IconFactory()
{
	std::string EDIT_POSITION_PATH = "pixmaps/position.png";
	std::string EDIT_GAME_PATH = "pixmaps/game.png";
	std::string SHOW_CANDIDATES_PATH = "pixmaps/candidates.png";
	
	Glib::RefPtr<Gtk::IconFactory> factory = Gtk::IconFactory::create();
		
	add_stock_icon(factory, EDIT_POSITION_PATH, "edit position", "Edit position");
	add_stock_icon(factory, EDIT_GAME_PATH, "edit game", "Edit game");
	add_stock_icon(factory, SHOW_CANDIDATES_PATH, "show candidates", "Show candidates");
	
	factory->add_default(); //Add factory to list of factories.
	
	this->EDIT_POSITION_ICON = Gtk::StockID("edit position");
	this->EDIT_GAME_ICON = Gtk::StockID("edit game");
	this->SHOW_CANDIDATES_ICON = Gtk::StockID("show candidates");
}

IconFactory::~IconFactory()
{
	
}

void IconFactory::add_stock_icon( const Glib::RefPtr<Gtk::IconFactory> &factory,
								  const std::string& filepath,								  
                                  const std::string& id,
                                  const std::string& label )
{	
	Gtk::IconSource source;
	
	try
	{
		//This throws an exception if the file is not found:
		//source.set_pixbuf(Gdk::Pixbuf::create_from_file(filepath));
		const Glib::RefPtr<Gdk::Pixbuf>& pixbuf = Gdk::Pixbuf::create_from_file(filepath.c_str());
		source.set_pixbuf(pixbuf);
	}
	catch(const Glib::Exception& ex)
	{
		std::cout << ex.what() << std::endl;
	}

	source.set_size(Gtk::ICON_SIZE_SMALL_TOOLBAR);
	source.set_size_wildcarded(); //Icon may be scaled.

	Glib::RefPtr<Gtk::IconSet> icon_set = Gtk::IconSet::create();
	icon_set->add_source(source); //More than one source per set is allowed.

	const Gtk::StockID stock_id(id);
	factory->add(stock_id, icon_set);
	Gtk::Stock::add(Gtk::StockItem(stock_id, label));
}
